;=========================================================================
; KOTVYSK.lsp    Vkov kty   (Command function for AutoCAD)
; (c) Copyright 2007 ARmenu, GGmenu
; Version:   1.3 - Seiner
; 2011
; verze: 1.63-EN+CZ - alfred (alfred.samca@seznam.cz , http://alfredcadpage.wz.cz/)
;-------------------------------------------------------------------------
; Author: ARmenu
; Update: PepaR (pepa.forum@centrum.cz , http://www.jremes.cz)
; Thanks for developing: Alfred, Seiner, Pajda
;
; Description / popis funkce:
; Tool for Autodesk AutoCAD for insert spot height and automatic fill value of height. 
; LISP tools get Y coordinate and write this valie as text to the atribute of spot height. Tool automatic adding prefix +/-by the possition a height depend on base level. 
; Its necesry put blocks Kota_vysky_R_GG and Kota_vysky_R_GG-POLE into AutoCADs Support Paths (see OPTIONS, tab Files).
;
; Zjist vku a zape ji jako atribut bloku.
;
;======================================================================================
;======================================================================================
; Command options:
; "VKS" Spot height (static)  inserting block Kota_vysky_R_GG
; "VKS-NADM" Spot height (static)  inserting block Kota_vysky_R_GG (prefix + is not added)
; "VKS-POLE" Spot height (dynamic) with dynamic field - inserting block Kota_vysky_R_GG-POLE
;             Value of height in dynamic block is also dynamic and if move a spot height a value is changed too.
;             For correct display a valu yu need to save, print or refresh drawing. Prefix + is neccesary input manually.
; "VKO" Update height value in static spot height Kota_vysky_R_GG
; "VKNULA" Set origin (0,000) for input spot height.
; "VKNULAZPET" Recover origin (0,000) back to default value.
;--------------------------------------------------------------
; Popis pkaz:
;  "VKS" Vkov kta - vkld blok 'Kota_vysky_R_GG' nebo 'Kota_vysky_R_GG.dwg'
;  "VKS-POLE" Vkov kta s polem - automaticky je v poli zobrazena souradnice Y mista vlozeni bloku.
;             Vklada blok 'Kota_vysky_R_GG-POLE' (Kota_vysky_R_GG-POLE.dwg). U tohoto bloku se pro kladne hodnoty NEZOBRAZUJE znamenko "+".
;  "VKO" Oprava hodnoty vkov kty "Kota_vysky_R_GG" a predchozich "vk1, vk2, ... vk8, vkota, KOTAVYSK"
;  "VKNULA" Nastav potek (0,000) pro ktovn
;  "VKNULAZPET" Vrt potek (0,000) zpt na pvodn hodnotu
;  "VKS-NADM" - pidna funkce, kter vkld ktu bez vodnho plusu

;======================================================================================
;======================================================================================
; NOTE:
; Scale of block depends on actual dimension style settings and units in drawing - INSUNITS. Scale of block is that height of attribut in block is the same as height of font
;in actual dimenzion style. Number of decimal places is by setting LUPREC (in setting UNITS). Formating of attribut value is by DIMLUNIT.
;If is actual dimension style set to "annotation"(DIMANNO=1), block scale is by: CANNOSCALEVALUE a DIMTXT
;If isn't actual dimension style set to "annotation" (DIMANNO=0), block scale is by: DIMSCALE a DIMTXT
;--------------------------------------------------------------
;POZNMKA:
;Metko vkldanho bloku zavis na nastaveni ktovacho stylu a jednotkch vkresu - INSUNITS. Mtko bloku je takov aby velikost psma atributu bloku byla stejn
;jako velikost psma u aktulnho ktovacho stylu. Poet desetinnch mst je stejn jako je v promnn LUPREC (v nasteven UNITS). Formtovn hodnoty je dle promnn DIMLUNIT.
;
;Pokud je ktovac styl jako "poznmka" (DIMANNO=1), tak velikost bloku zvis na promnnch: CANNOSCALEVALUE a DIMTXT
;Pokud nen ktovac styl jako "poznmka" (DIMANNO=0), tak velikost bloku zvis na promnnch: DIMSCALE a DIMTXT
;Reim ktovacho stylu "Mtko dle rozvren" nen podporovn.

;======================================================================================
;======================================================================================
;SETTING:

;LANGUAGE - czech or english
(setq GGmenuKotvysk-Lang "CS") ; must bee 'CS' or 'EN'
;(setq GGmenuKotvysk-Lang "EN") ; must bee 'CS' or 'EN'


; nastaveni nazvu bloku pro funkce: VKS, VKS-NADM, VKO
; block name settings for function: VKS, VKS-NADM, VKO
(SETQ GGmenu-jmeno_bloku-staticka_kacena "Kota_vysky_R_GG")           ;originalni nazev bloku/original block name: "Kota_vysky_R_GG"

; nastaveni nazvu bloku pro funkce: VKS-POLE
; block name settings for function: VKS-POLE
(SETQ GGmenu-jmeno_bloku-kacena+pole-mm "Kota_vysky_R_GG-POLE-mm")    ;originalni nazev bloku/original block name: "Kota_vysky_R_GG-POLE-mm"
(SETQ GGmenu-jmeno_bloku-kacena+pole-m "Kota_vysky_R_GG-POLE-m")      ;originalni nazev bloku/original block name: "Kota_vysky_R_GG-POLE-m"
(SETQ GGmenu-jmeno_bloku-kacena+pole-in "Kota_vysky_R_GG-POLE-in")    ;originalni nazev bloku/original block name: "Kota_vysky_R_GG-POLE-in"

;============================================================================
;============================================================================

(defun k-err (msg)
  (setq *error* olderr olderr nil)
  (if olddimzin (progn (setvar "dimzin" olddimzin)(setq olddimzin nil)))
  (if olddimzin2 (progn (setvar "dimzin" olddimzin2)(setq olddimzin2 nil)))
  (if atrvloz   (progn (setvar "attreq" atrvloz)  (setq atrvloz nil)))
  (if oldosmode (progn (setvar "osmode" oldosmode)(setq oldosmode nil)))
  (print msg)
  (princ)
)

;============================================================================
(defun zjisti_vysku (ko nasobitel prefix / k y HODNOTA_KOTY format_cisla format_koty olddimzin2)
  	;nasobitel:
  	;	- pro mm nasobitel=1000; pro
  	;	- pro m nasobitel=1; pro 
  (setq y (cdr (assoc 10 (entget ko)))) ;nacte do y hodnotu bodu
  (setq y (trans y 0 1)) ; prevede z globalniho do aktualniho USS
  (setq y (cadr y))
  (if (< (abs y) 1e-011)(setq y 0)) ; melo by korigovat nepresnosti AutoCadu
  
  (setq HODNOTA_KOTY (/ y nasobitel))
  ;(setq y (/ (cadr (cdr (assoc 10 (entget ko)))) 1000)) ; zakomentovany puvodni prikaz

  (setq format_koty (getvar "DIMLUNIT"))
  (setq format_cisla 2)
  (cond
    ((= format_koty 1) (setq format_cisla 1))  ;Scientific
    ((= format_koty 2) (setq format_cisla 2))  ;Decimal
    ((= format_koty 3) (setq format_cisla 3))  ; Engineering (feet and decimal inches)
    ((= format_koty 4) (setq format_cisla 4))  ; Architectural (feet and fractional inches)
    ((= format_koty 5) (setq format_cisla 5))  ;Fractional
    ((= format_koty 6) (setq format_cisla 2))  ;Decimal
  ) ; cond

  (if (and (= 1 (getvar "INSUNITS" )) (= 4 (getvar "DIMLUNIT")))
    (progn
      (setq olddimzin2 (getvar "dimzin"))
      (setvar "dimzin" 1)
    )
  )
  
  (cond
    ((> y 0) (setq text (strcat prefix (rtos HODNOTA_KOTY format_cisla (getvar "LUPREC")))))
    ((= y 0) (setq text (strcat "%%P" (rtos 0.0 format_cisla (getvar "LUPREC")))))
    ((< y 0) (setq text (rtos HODNOTA_KOTY format_cisla (getvar "LUPREC"))))
  ) ; cond

  (setq k (entnext ko))
  (setq k (entget k))
  (setq k (subst (cons '1 (vl-string-subst "," "." text)) (assoc 1 k) k))
  (entmod k)
  (entupd ko)

  (if olddimzin2 (progn (setvar "dimzin" olddimzin2)(setq olddimzin2 nil)))
  (princ)
) ; defun

;============================================================================
;pouziti funkce  - (v_atributu_je_cislo JMENO_ENTITY_BLOKU_S_ATRIBUTEM)
;syntax          - (v_atributu_je_cislo NAME_OF_ENTIT_(BLOCK)_WIDTH_ ATRIBUT)
(defun v_atributu_je_cislo (entita / entita-atribut obsah_atributu  is_text n str) 
  (setq entita-atribut (entnext entita)) 
  (if (/= entita-atribut nil)
    (progn
	  (if (= (cdr (assoc 0 (entget entita-atribut))) "ATTRIB")
	    (progn
		  (setq obsah_atributu (cdr (assoc 1 (entget entita-atribut))))
		  (setq is_text T); pedpoklad, e je vybrn text s slem
		  (setq n 1)

		  (if (= (strcase (substr obsah_atributu n 3)) "%%P")
		    (setq n 4)
		    )
		  (repeat (+ (- (strlen obsah_atributu) n) 1)
		    (setq str (substr obsah_atributu n 1))
		    (if	(= is_text T)
		      (progn
			(if (or	(= str "1")
				(= str "2")
				(= str "3")
				(= str "4")
				(= str "5")
				(= str "6")
				(= str "7")
				(= str "8")
				(= str "9")
				(= str "0")
				(= str ".")
				(= str ",")
				(= str "/")
				(= str "'")
				(= str " ")
				(= str "\"")
				(and (= str "+") (= n 1) (> (strlen obsah_atributu) 1))
				(and (= str "-") (= n 1) (> (strlen obsah_atributu) 1))     ;PRO ZPORNOU HODNOTU
				(and (= str "-") (= "'" (substr obsah_atributu (- n 1) 1))) ;pro formt 0'-0"
			    );konec podmnky
			  (princ)
			  (progn
			    ;(princ " ...Text doesn't contain number!!!")
			    (setq is_text nil)
			  );progn
			);if
		      );progn
		    );if
		    (setq n (+ n 1))
		  );repeat
	     );progn
	    (progn
		;multilanguage-start **************************************
		(cond
		  ((= GGmenuKotvysk-Lang "EN") (print (strcat "Selected block '" (cdr (assoc 2 (entget entita))) "' has no attribute - function stopped!!! You try use invalid block probably. ")))
		  ((= GGmenuKotvysk-Lang "CS") (print (strcat "Vybran blok '"(cdr (assoc 2 (entget entita)))"' neobsahuje atribut - nelze pokraovat!!! Pravdpodobn vkldte chybn blok ")))
		)
		;multilanguage-end ****************************************
	      (setq is_text nil)
	     )
	  );if
      );progn
      (progn
	;multilanguage-start **************************************
	(cond
	  ((= GGmenuKotvysk-Lang "EN") (print (strcat "Selected block '"(cdr (assoc 2 (entget entita)))"' has no attribute - function stopped!!! You try use invalid block probably. ")))
	  ((= GGmenuKotvysk-Lang "CS") (print (strcat "Vybran blok '"(cdr (assoc 2 (entget entita)))"' neobsahuje atribut - nelze pokraovat!!! Pravdpodobn vkldte chybn blok ")))
	)
	;multilanguage-end ****************************************
	(setq is_text nil)
     )
    );if
  ;navratova hodnota funkce "true/false" - musi byt na konci funkce!!!
  ;return value of function "true/false" - must be in end of function!!!
  is_text
);defun


;============================================================================
;  nastaven potku pro ktovn/zero level settings 
(defun C:VKNULA ( / P1 pozadovana_vyska oldosmode)    
  (setq olderr *error*) (setq *error* k-err)
  (setq oldosmode (getvar "osmode")) 

  ;(setq P1 (getpoint "Ukate novou srovnvac rovinu: "))
  ;tohle se mi zd jako neastn peklad 
  ;(setq P1 (getpoint "Define new  origin (0,000) <0,0,0>:"))


  ;multilanguage-start **************************************
  (cond
    ((= GGmenuKotvysk-Lang "EN") (setq P1 (getpoint "Click to new elevation: ")))
    ((= GGmenuKotvysk-Lang "CS") (setq P1 (getpoint "Ukate novou srovnvac rovinu: ")))
    )
  ;multilanguage-end ****************************************
  
  (if (/= P1 nil)
    (progn
          (if (= 1 (getvar "INSUNITS" ))
	    (progn
	      ;multilanguage-start **************************************
	      (cond
		((= GGmenuKotvysk-Lang "EN") (setq pozadovana_vyska (getreal "Define value for elevation [in] <ENTER for 0.000 in>: ")))
		((= GGmenuKotvysk-Lang "CS") (setq pozadovana_vyska (getreal "Zadejte vku srovnvac roviny [palce] <ENTER pro 0.000 palc>: ")))
		)
	      ;multilanguage-end ****************************************
	    );progn
	    (progn
	      ;multilanguage-start **************************************
	      (cond
		((= GGmenuKotvysk-Lang "EN") (setq pozadovana_vyska (getreal "Define value for elevation [m] <ENTER for 0.000 m>: ")))
		((= GGmenuKotvysk-Lang "CS") (setq pozadovana_vyska (getreal "Zadejte vku srovnvac roviny [m] <ENTER pro 0.000 m>: ")))
		)
	      ;multilanguage-end ****************************************
	    );progn
          );if
	    
	  (if (= pozadovana_vyska nil)
	    (setq pozadovana_vyska 0)
	  )
	    
	  (cond
	      ((= 1 (getvar "INSUNITS" ))(setq pozadovana_vyska (* pozadovana_vyska 1))); jednotky jsou palce
	      ;((= 2 (getvar "INSUNITS" ))(setq pozadovana_vyska (* pozadovana_vyska 1))); jednotky jsou stopy
	      ((= 4 (getvar "INSUNITS" ))(setq pozadovana_vyska (* pozadovana_vyska 1000))); jednotky jsou milimetry
	      ((= 6 (getvar "INSUNITS" ))(setq pozadovana_vyska (* pozadovana_vyska 1)))   ; jednotky jsou metry
	      ;multilanguage-start **************************************
	      (progn
	        (cond
	          ((= GGmenuKotvysk-Lang "EN") (print "Units is not set up to 'm' or 'mm'. Entered high [m] can't convert to current units setings!!"))
	          ((= GGmenuKotvysk-Lang "CS") (print "Ve vkrese nejsou nastaveny jednotky na 'm' nebo 'mm'. Zadanou vku [m] nelze pevst na vkresov jednotky!!"))
	        );cond
	      );progn
	      ;multilanguage-end ****************************************
	  );cond
      
	  (setq P1 (list
		     (nth 0 P1)
		     (- (nth 1 P1) pozadovana_vyska)
		     (nth 2 P1)
		   )
	  )
	  ;(command "_UCS" "_DELETE" "*")
	  (command "_UCS" "_DELETE" "NULAVK")
	  (command "_UCS"  "_SAVE" "NULAVK")
      
          (setvar "osmode" 0)
	  (command "_UCS" "_New" P1)
          (setvar "osmode" oldosmode)
      );progn
      (progn
	;multilanguage-start **************************************
	(cond
	  ((= GGmenuKotvysk-Lang "EN") (print "Setting elevation level has not changed."))
	  ((= GGmenuKotvysk-Lang "CS") (print "Nastaven srovnvac roviny zstalo na pvodn hodnot."))
	)
        ;multilanguage-end ****************************************
      );progn
    );if
  (setq *error* olderr olderr nil)
  (print "End...")
  (print)
) ; defun


;============================================================================
(defun C:VKNULAZPET ()    ;  vrt zpt pvodn potek
  (if (tblsearch "ucs" "nulavk")
    (progn
      (command "_UCS" "_restore" "NULAVK")
      ;multilanguage-start **************************************
      (cond
	;((= GGmenuKotvysk-Lang "EN") (print "Origin (0,0,0) set up to default value."))
	((= GGmenuKotvysk-Lang "EN") (print "Setting previous elevation."))
	((= GGmenuKotvysk-Lang "CS") (print "Potek (0,0,0) byl vrcen na pvodn hodnotu."))
	)
      ;multilanguage-end ****************************************
    );progn
    (progn
      ;multilanguage-start **************************************
      (cond
	;((= GGmenuKotvysk-Lang "EN") (print "Origin is not possible to recover - Tool can't find UCS named 'NULAVK'"))
	((= GGmenuKotvysk-Lang "EN") (print "Previous elevation is not possible to recover - Tool can't find UCS named 'NULAVK'"))
	((= GGmenuKotvysk-Lang "CS") (print "Nelze obnovit pedchoz potek - nen uloen USS s nzvem 'NULAVK'"))
	)
      ;multilanguage-end ****************************************
    );progn
  );if
  (print "End...")
  (print)
) ; defun


;============================================================================
;  oprava hodnoty u vk. kot
(defun C:VKO ( / ko d selekce i blname pocet_modifikovanych pocet_bez_cisla nasobitel prvni_znak)
  (vl-load-com)
  (setq echo (getvar "cmdecho"))
  (setvar "cmdecho" 0)
  (setq olderr *error*)
  (setq *error* k-err)
  ;zjisteni jednotek
  (setq nasobitel nil)
  (cond
      ((= 1 (getvar "INSUNITS" ))(setq nasobitel 1))
      ((= 2 (getvar "INSUNITS" ))(setq nasobitel 1))
      ((= 4 (getvar "INSUNITS" ))(setq nasobitel 1000))
      ((= 6 (getvar "INSUNITS" ))(setq nasobitel 1))
      (progn

         ;multilanguage-start **************************************
         (cond
	   ((= GGmenuKotvysk-Lang "EN") (progn (print "Units is not set up to 'm', 'mm' or 'inch'. Update spot height value failed.")(setq nasobitel 0)) )
	   ((= GGmenuKotvysk-Lang "CS") (progn (print "Ve vykrese nejsou nastaveny jednotky na 'm' nebo 'mm'. Nelze aktualizovat hodnotu vky.")(setq nasobitel 0)) )
	   )
         ;multilanguage-end ****************************************
       
      );progn
  );cond
  
  (if (> nasobitel 0)
   (progn
    (setq selekce nil)
    ;multilanguage-start **************************************
    (cond
      ((= GGmenuKotvysk-Lang "EN") (prompt "\nSelect spot heights for updating value: "))
      ((= GGmenuKotvysk-Lang "CS") (prompt "\nVyberte vkov kty"))
      )
    ;multilanguage-end ****************************************
    (if (setq selekce (ssget '((0 . "INSERT"))))
      (progn
            (setq i 0)
            (setq pocet_modifikovanych 0)
      	    (setq pocet_bez_cisla 0)
      
	    (while (ssname selekce i)
	       (setq ko (ssname selekce i))
	       (setq d (entget ko))
	       (setq olddimzin (getvar "dimzin"))
	       (setvar "dimzin" 0)
	       ; zjisteni jmena bloku (nutno takhle - u dynamickych bloku je jmeno *U*
	       (setq blname (vla-get-effectivename (vlax-ename->vla-object ko)))

	       (if   ; jmeno bloku je v listu
		    (/= nil
		      (vl-position blname
			      (list GGmenu-jmeno_bloku-staticka_kacena
				    "vk1"    "vk2"    "vk3"
				    "vk4"    "vk5"    "vk6"    "vk7"
				    "vk8"    "vkota"  "KOTAVYSK" 
				    "VK1"    "VK2"    "VK3"    "VK4"
				    "VK5"    "VK6"    "VK7"    "VK8" "VKOTA"
				     )
		      )
		     ); konec podminky
		     (progn
		       (if (v_atributu_je_cislo ko)
			 (progn
				(setq hodnota-string (cdr (assoc 1 (entget (entnext ko)))))
				(setq prvni_znak (substr hodnota-string 1 1))
				(cond
				  ((vl-position prvni_znak (list "0" "1" "2" "3" "4" "5" "6" "7" "8" "9")) (zjisti_vysku ko nasobitel ""));pedpoklad - nadmosk vka
				  ( (vl-position prvni_znak (list "+" "-" "%")) (zjisti_vysku ko nasobitel "+")); pedpoklad - relativn kta
				);cond
	   	            ;(zjisti_vysku ko nasobitel "+")
			    (setq pocet_modifikovanych (+ 1 pocet_modifikovanych))
			 );PROGN
			 (progn
			   ;multilanguage-start **************************************
			   (cond
			     ((= GGmenuKotvysk-Lang "EN") (print (strcat "atribude in block '" blname "' doesn't contain number")))
			     ((= GGmenuKotvysk-Lang "CS") (print (strcat "v atributu bloku '" blname "' neni cislo")))
			     )
			   ;multilanguage-end ****************************************
			   (setq pocet_bez_cisla (+ 1 pocet_bez_cisla))
			 );progn
		       );if
		     );progn
		     (progn
		       
		       ;multilanguage-start **************************************
		       (cond
			 ((= GGmenuKotvysk-Lang "EN") (print "Isn't spot heights."))
			 ((= GGmenuKotvysk-Lang "CS") (print "Nen vkov kota."))
			 )
		       ;multilanguage-end ****************************************
		       
		     );progn
	       ); if
               (setq i (+ i 1))
	    ); while
	
	    ;multilanguage-start **************************************
	    (cond
	      ((= GGmenuKotvysk-Lang "EN") (print (strcat "Updated " (rtos pocet_modifikovanych 2 0)" blocks from "(rtos (sslength selekce) 2 0)" selected. "(rtos pocet_bez_cisla 2 0)" blocks is not udpated, attribute doesn't contain number.")))
	      ((= GGmenuKotvysk-Lang "CS") (print (strcat "Bylo upraveno "(rtos pocet_modifikovanych 2 0)" blok z "(rtos (sslength selekce) 2 0)" vybranch. "(rtos pocet_bez_cisla 2 0) " blok() neaktulizovno, protoe neobsahuje slo.")))
	      )
	    ;multilanguage-end ****************************************
	
      	    (setvar "dimzin" olddimzin)
	    (setq olddimzin nil)
	  );progn
          (progn
	    ;multilanguage-start **************************************
	    (cond
	      ((= GGmenuKotvysk-Lang "EN") (print "nothing selected"))
	      ((= GGmenuKotvysk-Lang "CS") (print "dn vbr"))
	      )
	    ;multilanguage-end ****************************************
	  );progn
    );if
   );progn
  );if


  (setq *error* olderr olderr nil)
  (setvar "cmdecho" echo)
  (print "End...")
  (princ)
) ; defun


;============================================================================
; vloen vkov kty - blok s nzvem "Kota_vysky_R_GG" (hodnota ulozena v promenne 'GGmenu-jmeno_bloku-staticka_kacena')
;- do vykresu kreslenem v metrech nebo v milimetrech
(defun c:VKS ()
   (gg-vyskova_kota_staticka "+")
   (print "End...")
   (princ)
);defun


;============================================================================
; vloen vkov kty - blok s nzvem "Kota_vysky_R_GG" (hodnota ulozena v promenne 'GGmenu-jmeno_bloku-staticka_kacena')
; - do vykresu kreslenem v metrech nebo v milimetrech
(defun c:VKS-NADM ()
   (gg-vyskova_kota_staticka "")
   (print "End...")
   (princ)
);defun


;============================================================================
;hlavn funkce pro 'VKS' a 'VKS-NADM'
;main procedure for funkctions 'VKS' a 'VKS-NADM'
(defun gg-vyskova_kota_staticka (prefix / jm_bloku olddimzin atrvloz ko inspoint echo meritko prevod_jednotek oldosmode dbo tot i delka_atributu newval koty_text_style-vyska VyskaTextuAktualniKoty)
  (vl-load-com)
  (setq jm_bloku GGmenu-jmeno_bloku-staticka_kacena)
  (setq nasobitel 1 prevod_jednotek 1)
  (cond
      ((= 1 (getvar "INSUNITS" ))(setq nasobitel 1   prevod_jednotek 25.4))               ;palce
      ;((= 1 (getvar "INSUNITS" ))(setq nasobitel 1   prevod_jednotek 1))                 ;palce
      ((= 2 (getvar "INSUNITS" ))(setq nasobitel 1   prevod_jednotek (* 12 25.4)))        ;stopy
      ((= 4 (getvar "INSUNITS" ))(setq nasobitel 1000 prevod_jednotek 1))                 ;mm
      ((= 6 (getvar "INSUNITS" ))(setq nasobitel 1 prevod_jednotek 1000))                 ;metry
      (progn
       ;multilanguage-start **************************************
       (cond
	 ((= GGmenuKotvysk-Lang "EN")
	    (alert
                "Units for drawing ( 'm', 'mm' or 'in') is not defined.
                Please define units (command 'UNITS') for correct 
                working a utility! Insertion scale for block use 
                value variable 'DIMSCALE'."
            ) ;alert
	 )
	 ((= GGmenuKotvysk-Lang "CS")
	    (alert
                "Ve vykrese nejsou nastaveny jednotky na 'm', 'mm' nebo 'palce'.
                Pro sprvn fungovn funkce a nastaven mtka bloku 
                je nutn mt sprvn nastaveny jednotky!!! Bude pouit blok pro jednotky 'metr'.
                Mtko vloen bloku vk. koty bude nastaveno podle promnn 'DIMSCALE'
                a dle standardnho chovn AutoCADu pro vkldn blok rznch jednotek.
                Jednotky se nastavuj pkazem 'UNITS'."
            ) ;alert
	 )
	 );cond
       ;multilanguage-end ****************************************
      );progn
  );cond

  (if (or (tblsearch "block" jm_bloku) (findfile (strcat jm_bloku ".dwg")))
    (progn
	  (setq olddimzin (getvar "dimzin")) (setvar "dimzin" 0)
      	  (setq oldosmode (getvar "osmode")) 
	  (setq atrvloz (getvar "attreq"))   (setvar "attreq" 0)
          (setq echo (getvar "cmdecho"))     (setvar "cmdecho" 0)
          (setq olderr *error*)              (setq *error* k-err)

	  (setq inspoint 0)
	  (while (/= inspoint nil)

	    ;multilanguage-start **************************************
	    (cond
	      ((= GGmenuKotvysk-Lang "EN") (setq inspoint (getpoint "\nSelect location for spot height : ")))
	      ((= GGmenuKotvysk-Lang "CS") (setq inspoint (getpoint "\nUkate bod umstn kty : ")))
	      )
	    ;multilanguage-end ****************************************


    ;nastaven mtka pro vloen bloku - zatek
	    (setq koty_text_style-vyska (cdr (ASSOC 40 (tblsearch "STYLE" (getvar "DIMTXSTY")))))
	    (if (= koty_text_style-vyska 0)
	      (setq VyskaTextuAktualniKoty (* (getvar "dimscale") (getvar "DIMTXT")))
	      (setq VyskaTextuAktualniKoty koty_text_style-vyska)
	    )
    
	    ;uprava - poznmky
	    (if (= 0 (getvar "DIMANNO"))  ; 0- kotovac styl BEZ poznmek; 1-kotovac styl S poznmek
	       (setq meritko (* prevod_jednotek (/ VyskaTextuAktualniKoty 2.5)))                                 ;pzn: 2.5 - vyska atributu v bloku
	       (setq meritko (* prevod_jednotek (/ (* (/ 1 (getvar "CANNOSCALEVALUE")) (getvar "DIMTXT")) 2.5))) ;pzn: 2.5 - vyska atributu v bloku
	    );if
	    
	    ;******************************************* xxxxxxxxxxxxxxxxxxxx
	    (if (= meritko 0)
	      (progn
		;multilanguage-start **************************************
		(cond
		  ((= GGmenuKotvysk-Lang "EN") (print "WARNING: DIMSCALE=0, block will bee insert width scale=1"))
		  ((= GGmenuKotvysk-Lang "CS") (print "POZOR: DIMSCALE=0, blok bude vloen s mtkem=1"))
		  )
		;multilanguage-end ****************************************
		(setq meritko 1)
	      );progn
	    );if
    ;nastaven mtka pro vloen bloku - konec

	    (if (/= inspoint nil)
	      (progn
		 (setvar "osmode" 0)
		 (command "_INSERT" jm_bloku inspoint meritko "")
		 (setvar "osmode" oldosmode)
	   	 (setq ko (entlast))
		 (if (/= (entnext ko) nil)
		      ;uprava - delka koty
		      (progn
		          (zjisti_vysku ko nasobitel prefix) ; pozor - 'prefix' je hlavn parametr funkce
			  ;zjisteni delky atributu a modifikace dynamick vlastnosti "Dlka kty" nebo "Dimension Lenght"
			  (setq delka_atributu (textbox (entget (entnext ko))))
			  (setq delka_atributu (- (car (cadr delka_atributu)) (car (car delka_atributu))))
			  (setq newval (* 1.07 delka_atributu)) ;pzn: nsobitel - podle toho se dolad dlka kaeny
			  (setq dbo (vlax-ename->vla-object ko))
			  (if (vlax-property-available-p dbo 'IsDynamicBlock)
			     (progn
                                (setq sal (vlax-safearray->list (vlax-variant-value (vla-getdynamicblockproperties dbo)))
			              tot (length sal)
			              i 0
				 )
				 (while (< i tot)
					(if  (or (= (vlax-get-property (nth i sal) "PropertyName") "Dlka kty")
						 (= (vlax-get-property (nth i sal) "PropertyName") "Dimension Lenght")
					     );or
					   (progn
					        (setq curval (vlax-variant-value (vlax-get-property (nth i sal) "Value")))
					        (if (< curval newval)
						  (vlax-put-property (nth i sal) "Value" newval)
						)
					        (setq i tot)
					   )
					(setq i (1+ i))
					)
				 );while
	       
			     );progn
			     (progn
			       ;multilanguage-start **************************************
			       (cond
				 ((= GGmenuKotvysk-Lang "EN") (print "Block isn't dynamic..."))
				 ((= GGmenuKotvysk-Lang "CS") (print "Blok nen dynamick..."))
				 )
			       ;multilanguage-end ****************************************
			     );progn
                          );if
                          
                          ;KONEC zjisteni delky atributu a modifikace dynamick vlastnosti "dlka koty"
			
		      );progn
		      (progn

			;multilanguage-start **************************************
			(cond
			  ((= GGmenuKotvysk-Lang "EN") (print (strcat "Error: Inserted block '"(cdr (assoc 2 (entget ko)))"' has no attribute - writing heigt value failed!!! You use invalid block. ")))
			  ((= GGmenuKotvysk-Lang "CS") (print (strcat "Error: Vloen blok '"(cdr (assoc 2 (entget ko)))"' neobsahuje atribut - nelze zapsat vku!!! Pravdpodobn vkldte chybn blok. ")))
			  )
			;multilanguage-end ****************************************
		
		      );progn
		 );if
	      )
	    );if
	  );while

  	  (setq *error* olderr olderr nil)
  	  (setvar "cmdecho" echo)
          (setq oldosmode nil)
	  (setvar "dimzin" olddimzin)(setq olddimzin nil)
	  (setvar "attreq" atrvloz)(setq atrvloz nil)
      );progn
      (progn
	;multilanguage-start **************************************
	(cond
	  ((= GGmenuKotvysk-Lang "EN") (print (strcat "Block '" jm_bloku "' with spot height is missing. End.")))
	  ((= GGmenuKotvysk-Lang "CS") (print (strcat "Blok '" jm_bloku "' s vykovou ktou nelze najt. Konec.")))
	  )
	;multilanguage-end ****************************************
      );progn
    );if
  (print)
)


;============================================================================
; vloen vkov kty - blok s nzvem "Kota_vysky_R_GG-POLE" (ULOZENO V PROMENNE 'GGmenu-jmeno_bloku-kacena+pole')
(defun c:VKS-POLE (/ jm_bloku olddimzin atrvloz inspoint echo oldosmode meritko prevod_jednotek oldosmode dbo tot i delka_atributu newval)

  ;multilanguage-start **************************************
  (cond
    ((= GGmenuKotvysk-Lang "EN") (print "Command insert dynamic block spot height with text field contains Y coordinate inserted block. Use command 'REGENALL', save or print drawing for udpate height value."))
    ((= GGmenuKotvysk-Lang "CS") (print "Funkce vkld blok s textovm polem, kter automaticky zobrazuje hodnotu souadnice Y. Hodnota se aktualizuje pi regeneraci nebo tisku. Pro kladn hodnoty nelze automaticky zobrazit znamnko '+'."))
    )
  ;multilanguage-end ****************************************
  
  (setq jm_bloku GGmenu-jmeno_bloku-kacena+pole-m );
  (cond
      ((= 1 (getvar "INSUNITS" ))(setq jm_bloku GGmenu-jmeno_bloku-kacena+pole-in ))     ;in
      ((= 4 (getvar "INSUNITS" ))(setq jm_bloku GGmenu-jmeno_bloku-kacena+pole-mm ))     ;mm
      ((= 6 (getvar "INSUNITS" ))(setq jm_bloku GGmenu-jmeno_bloku-kacena+pole-m  ))     ;metry
      (progn
       ;multilanguage-start **************************************
       (cond
	 ((= GGmenuKotvysk-Lang "EN")
	    (alert
                "Units for drawing ( 'm', 'mm' or 'in') is not defined.
                Please define units (command 'UNITS') for correct 
                working a utility! Insertion scale for block use 
                value variable 'DIMSCALE'."
            ) ;alert
	 )
	 ((= GGmenuKotvysk-Lang "CS")
	    (alert
                "Ve vykrese nejsou nastaveny jednotky na 'm', 'mm' nebo 'palce'.
                Pro sprvn fungovn funkce a nastaven mtka bloku 
                je nutn mt sprvn nastaveny jednotky!!! Bude pouit blok pro jednotky 'metr'.
                Mtko vloen bloku vk. koty bude nastaveno podle promnn 'DIMSCALE'
                a dle standardnho chovn AutoCADu pro vkldn blok rznch jednotek.
                Jednotky se nastavuj pkazem 'UNITS'."
            ) ;alert
	 )
	 );cond
       ;multilanguage-end ****************************************
       
       
    
       );progn
    );cond
 
  
  ;(setq jm_bloku GGmenu-jmeno_bloku-kacena+pole)
  (if (or (tblsearch "block" jm_bloku) (findfile (strcat jm_bloku ".dwg")))
    (progn
	  (setq olddimzin (getvar "dimzin")) (setvar "dimzin" 0)
      	  (setq oldosmode (getvar "osmode")) 
	  (setq atrvloz (getvar "attreq"))   (setvar "attreq" 0)
          (setq echo (getvar "cmdecho"))     (setvar "cmdecho" 0)
          (setq olderr *error*)              (setq *error* k-err)
	  (setq inspoint 0)
	  (while (/= inspoint nil)
	    ;multilanguage-start **************************************
	    (cond
	      ((= GGmenuKotvysk-Lang "EN") (setq inspoint (getpoint "\nSelect location for spot height : ")))
	      ((= GGmenuKotvysk-Lang "CS") (setq inspoint (getpoint "\nUkate bod umstn kty : ")))
	      )
	    ;multilanguage-end ****************************************
	    
	    (setq prevod_jednotek 1);pouze pro kompatibilitu - aby st s nastavenm mtka byla stejn jako ve funkci (gg-vyskova_kota_staticka)

    ;nastaven mtka pro vloen bloku - zatek
	    (setq koty_text_style-vyska (cdr (ASSOC 40 (tblsearch "STYLE" (getvar "DIMTXSTY")))))
	    (if (= koty_text_style-vyska 0)
	      (setq VyskaTextuAktualniKoty (* (getvar "dimscale") (getvar "DIMTXT")))
	      (setq VyskaTextuAktualniKoty koty_text_style-vyska)
	    )
    
	    ;uprava - poznmky
	    (if (= 0 (getvar "DIMANNO"))  ; 0- kotovac styl BEZ poznmek; 1-kotovac styl S poznmek
	       (setq meritko (* prevod_jednotek (/ VyskaTextuAktualniKoty 2.5)))                                 ;pzn: 2.5 - vyska atributu v bloku
	       (setq meritko (* prevod_jednotek (/ (* (/ 1 (getvar "CANNOSCALEVALUE")) (getvar "DIMTXT")) 2.5))) ;pzn: 2.5 - vyska atributu v bloku
	    );if
	    
	    ;******************************************* xxxxxxxxxxxxxxxxxxxx
	    (if (= meritko 0)
	      (progn
		;multilanguage-start **************************************
		(cond
		  ((= GGmenuKotvysk-Lang "EN") (print "WARNING: DIMSCALE=0, block will bee insert width scale=1"))
		  ((= GGmenuKotvysk-Lang "CS") (print "POZOR: DIMSCALE=0, blok bude vloen s mtkem=1"))
		  )
		;multilanguage-end ****************************************
		(setq meritko 1)
	      );progn
	    );if
    ;nastaven mtka pro vloen bloku - konec
	    
	    (if (/= inspoint nil)
	      (progn
	         (setvar "osmode" 0)
		 (command "_INSERT" jm_bloku inspoint meritko "")
		 (setvar "osmode" oldosmode)

                 (setq ko (entlast))
		 (if (/= (entnext ko) nil)
		      ;uprava - delka koty
		      (progn
			  ;zjisteni delky atributu a modifikace dynamick vlastnosti "Dlka kty" nebo "Dimension Lenght"
			  (setq delka_atributu (textbox (entget (entnext ko))))
			  (setq delka_atributu (- (car (cadr delka_atributu)) (car (car delka_atributu))))
			  (setq newval (* 1.07 delka_atributu)) ;pzn: nsobitel - podle toho se dolad dlka kaeny
			  (setq dbo (vlax-ename->vla-object ko))
			  (if (vlax-property-available-p dbo 'IsDynamicBlock)
			     (progn
                                (setq sal (vlax-safearray->list (vlax-variant-value (vla-getdynamicblockproperties dbo)))
			              tot (length sal)
			              i 0
				 )
				 (while (< i tot)
					(if (or (= (vlax-get-property (nth i sal) "PropertyName") "Dlka kty")
						 (= (vlax-get-property (nth i sal) "PropertyName") "Dimension Lenght")
					     );or
					   (progn
					        (setq curval (vlax-variant-value (vlax-get-property (nth i sal) "Value")))
					        (if (< curval newval)
						  (vlax-put-property (nth i sal) "Value" newval)
						)
					        (setq i tot)
					   )
					(setq i (1+ i))
					)
				 );while
	       
			     );progn
			     (progn
			       ;multilanguage-start **************************************
			       (cond
				 ((= GGmenuKotvysk-Lang "EN") (print "Block isn't dynamic..."))
				 ((= GGmenuKotvysk-Lang "CS") (print "Blok nen dynamick..."))
				 )
			       ;multilanguage-end ****************************************
			     );progn
                          );if
                          
                          ;KONEC zjisteni delky atributu a modifikace dynamick vlastnosti "dlka koty"
			
		      );progn
		)
		;*************************************************
	      );progn
	    );if
	  );while

  	  (setq *error* olderr olderr nil)
  	  (setvar "cmdecho" echo)
          (setq oldosmode nil)
	  (setvar "dimzin" olddimzin)(setq olddimzin nil)
	  (setvar "attreq" atrvloz)(setq atrvloz nil)
      );progn
      (progn
	;multilanguage-start **************************************
	(cond
	  ((= GGmenuKotvysk-Lang "EN") (print (strcat "Block '" jm_bloku "' with spot height is missing. End.")))
	  ((= GGmenuKotvysk-Lang "CS") (print (strcat "Blok '" jm_bloku "' s vykovou ktou nelze najt. Konec.")))
	  )
	;multilanguage-end ****************************************
      );progn
    );if
  (print "End...")
  (print)
)



;======================================================================================
;hlka pi natn / report while loading

(cond
  ((= GGmenuKotvysk-Lang "EN")(print "Language is set to english ..."))
  ((= GGmenuKotvysk-Lang "CS")(print "Je nastavena etina ..."))
  (print "Bad settings of 'GGmenuKotvysk-Lang' - must bee 'CS' or 'EN'")
)
(print)

;multilanguage-start **************************************
(cond
  ((= GGmenuKotvysk-Lang "EN")
   (progn
     (print "Utility for spot heights loaded. Commands:")
     (print (strcat "    'VKS' ... spot height (static)  inserting (block '" GGmenu-jmeno_bloku-staticka_kacena "') "))
     (print (strcat "    'VKO' ... update height value in static spot height  '" GGmenu-jmeno_bloku-staticka_kacena " ' "))
     (print (strcat "    'VKS-POLE' ... spot height (dynamic) with dynamic field - inserting blocks :"))
     (print (strcat "     '" GGmenu-jmeno_bloku-kacena+pole-m "' or '" GGmenu-jmeno_bloku-kacena+pole-mm "' (depends on units)"))
     (print (strcat "    'VKS-NADM' ... spot height (static)  inserting block '" GGmenu-jmeno_bloku-staticka_kacena "' (prefix + is not added)"))
     (print "    'VKNULA'      ... set new elevation ")
     (print "    'VKNULAZPET'  ... set previous elevation ")
   )
  )
  ((= GGmenuKotvysk-Lang "CS")
    (progn
      (print "Natena funkce pro vkov kty. Spout se:")
      (print (strcat "    'VKS' ... vloen relativn vkov kty  (blok '" GGmenu-jmeno_bloku-staticka_kacena "') "))
      (print (strcat "    'VKO' ... aktualizace bloku vkov kty '" GGmenu-jmeno_bloku-staticka_kacena " ' "))
      (print (strcat "    'VKS-POLE' ... vloen vkov kty s dynamickm polem :"))
      (print (strcat "     '" GGmenu-jmeno_bloku-kacena+pole-m "' nebo '" GGmenu-jmeno_bloku-kacena+pole-mm "' (dle jednotek)"))
      (print (strcat "    'VKS-NADM' ... vloen vkov kty s nadmoskou vkou '" GGmenu-jmeno_bloku-staticka_kacena "'"))
      (print "    'VKNULA'      ... nastaven nov srovnvac roviny")
      (print "    'VKNULAZPET'  ... nastaven pedchoz srovnvac roviny")
    )
  )
)
;multilanguage-end ****************************************

(PRINC)
